=================
Development Notes
=================

Testing
=======

To run django-tidings' tests, install
`tox <https://tox.readthedocs.io/en/latest/>`_ and run it::

  $ pip install tox
  $ tox

Documentation
=============

To build the docs, install Sphinx and run this::

  make docs
